0.1.1 (2014-09-18)
------------------

- Minor release adding and cleaning up lots of service documentation. (#14)
- Fixes a small bug when no capakey username or password was set and the capakey
  service was included. 

0.1.0 (2014-09-05)
------------------

- First stable release, matches with CRABpy 0.4.1
- Exposes CRAB and CAPAKEY gateways.
- CRAB Gateway also exposes some Provincie objects. (#13)
- CRAB and CAPAKEy can be configured independently. (#11)

0.1.0a2 (2014-04-30)
--------------------

- Still alpha.
- Coveralls support.
- Proxy settings in ini file. (#5)
- Range headers. (#9)

0.1.0a1 (2014-03-19)
--------------------

- Initial version
